pub struct SqlBackupRunsService { /* private fields */ }Expand description
Implements a client for the Cloud SQL Admin API.
Example
let client = SqlBackupRunsService::builder().build().await?;
let response = client.delete()
/* set fields */
.send().await?;
println!("response {:?}", response);Service Description
Service for managing database backups.
Configuration
To configure SqlBackupRunsService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://sqladmin.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
SqlBackupRunsService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap SqlBackupRunsService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl SqlBackupRunsService
impl SqlBackupRunsService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for SqlBackupRunsService.
let client = SqlBackupRunsService::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: SqlBackupRunsService + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: SqlBackupRunsService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn delete(&self) -> Delete
pub fn delete(&self) -> Delete
Deletes the backup taken by a backup run.
Example
use google_cloud_sql_v1::Result;
async fn sample(
client: &SqlBackupRunsService
) -> Result<()> {
let response = client.delete()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get(&self) -> Get
pub fn get(&self) -> Get
Retrieves a resource containing information about a backup run.
Example
use google_cloud_sql_v1::Result;
async fn sample(
client: &SqlBackupRunsService
) -> Result<()> {
let response = client.get()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn insert(&self) -> Insert
pub fn insert(&self) -> Insert
Creates a new backup run on demand.
Example
use google_cloud_sql_v1::Result;
async fn sample(
client: &SqlBackupRunsService
) -> Result<()> {
let response = client.insert()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list(&self) -> List
pub fn list(&self) -> List
Lists all backup runs associated with the project or a given instance and configuration in the reverse chronological order of the backup initiation time.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_sql_v1::Result;
async fn sample(
client: &SqlBackupRunsService
) -> Result<()> {
let mut list = client.list()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Trait Implementations
Sourceimpl Clone for SqlBackupRunsService
impl Clone for SqlBackupRunsService
Sourcefn clone(&self) -> SqlBackupRunsService
fn clone(&self) -> SqlBackupRunsService
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more