pub struct SqlConnectService { /* private fields */ }Expand description
Implements a client for the Cloud SQL Admin API.
Example
let client = SqlConnectService::builder().build().await?;
let response = client.get_connect_settings()
/* set fields */
.send().await?;
println!("response {:?}", response);Service Description
Cloud SQL connect service.
Configuration
To configure SqlConnectService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://sqladmin.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
SqlConnectService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap SqlConnectService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl SqlConnectService
impl SqlConnectService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for SqlConnectService.
let client = SqlConnectService::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: SqlConnectService + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: SqlConnectService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn get_connect_settings(&self) -> GetConnectSettings
pub fn get_connect_settings(&self) -> GetConnectSettings
Retrieves connect settings about a Cloud SQL instance.
Example
use google_cloud_sql_v1::Result;
async fn sample(
client: &SqlConnectService
) -> Result<()> {
let response = client.get_connect_settings()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn generate_ephemeral_cert(&self) -> GenerateEphemeralCert
pub fn generate_ephemeral_cert(&self) -> GenerateEphemeralCert
Generates a short-lived X509 certificate containing the provided public key and signed by a private key specific to the target instance. Users may use the certificate to authenticate as themselves when connecting to the database.
Example
use google_cloud_sql_v1::Result;
async fn sample(
client: &SqlConnectService
) -> Result<()> {
let response = client.generate_ephemeral_cert()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Trait Implementations
Sourceimpl Clone for SqlConnectService
impl Clone for SqlConnectService
Sourcefn clone(&self) -> SqlConnectService
fn clone(&self) -> SqlConnectService
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more