pub struct SqlDatabasesService { /* private fields */ }Expand description
Implements a client for the Cloud SQL Admin API.
Example
let client = SqlDatabasesService::builder().build().await?;
let response = client.delete()
/* set fields */
.send().await?;
println!("response {:?}", response);Service Description
Service to manage databases.
Configuration
To configure SqlDatabasesService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://sqladmin.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
SqlDatabasesService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap SqlDatabasesService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl SqlDatabasesService
impl SqlDatabasesService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for SqlDatabasesService.
let client = SqlDatabasesService::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: SqlDatabasesService + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: SqlDatabasesService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn delete(&self) -> Delete
pub fn delete(&self) -> Delete
Deletes a database from a Cloud SQL instance.
Example
use google_cloud_sql_v1::Result;
async fn sample(
client: &SqlDatabasesService
) -> Result<()> {
let response = client.delete()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get(&self) -> Get
pub fn get(&self) -> Get
Retrieves a resource containing information about a database inside a Cloud SQL instance.
Example
use google_cloud_sql_v1::Result;
async fn sample(
client: &SqlDatabasesService
) -> Result<()> {
let response = client.get()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn insert(&self) -> Insert
pub fn insert(&self) -> Insert
Inserts a resource containing information about a database inside a Cloud SQL instance.
Note: You can’t modify the default character set and collation.
Example
use google_cloud_sql_v1::Result;
async fn sample(
client: &SqlDatabasesService
) -> Result<()> {
let response = client.insert()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list(&self) -> List
pub fn list(&self) -> List
Lists databases in the specified Cloud SQL instance.
Example
use google_cloud_sql_v1::Result;
async fn sample(
client: &SqlDatabasesService
) -> Result<()> {
let response = client.list()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn patch(&self) -> Patch
pub fn patch(&self) -> Patch
Partially updates a resource containing information about a database inside a Cloud SQL instance. This method supports patch semantics.
Example
use google_cloud_sql_v1::Result;
async fn sample(
client: &SqlDatabasesService
) -> Result<()> {
let response = client.patch()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update(&self) -> Update
pub fn update(&self) -> Update
Updates a resource containing information about a database inside a Cloud SQL instance.
Example
use google_cloud_sql_v1::Result;
async fn sample(
client: &SqlDatabasesService
) -> Result<()> {
let response = client.update()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Trait Implementations
Sourceimpl Clone for SqlDatabasesService
impl Clone for SqlDatabasesService
Sourcefn clone(&self) -> SqlDatabasesService
fn clone(&self) -> SqlDatabasesService
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more