pub struct SqlOperationsService { /* private fields */ }Expand description
Implements a client for the Cloud SQL Admin API.
Example
let client = SqlOperationsService::builder().build().await?;
let response = client.get()
/* set fields */
.send().await?;
println!("response {:?}", response);Service Description
Service to fetch operations for database instances.
Configuration
To configure SqlOperationsService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://sqladmin.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
SqlOperationsService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap SqlOperationsService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl SqlOperationsService
impl SqlOperationsService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for SqlOperationsService.
let client = SqlOperationsService::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: SqlOperationsService + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: SqlOperationsService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn get(&self) -> Get
pub fn get(&self) -> Get
Retrieves an instance operation that has been performed on an instance.
Example
use google_cloud_sql_v1::Result;
async fn sample(
client: &SqlOperationsService
) -> Result<()> {
let response = client.get()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list(&self) -> List
pub fn list(&self) -> List
Lists all instance operations that have been performed on the given Cloud SQL instance in the reverse chronological order of the start time.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_sql_v1::Result;
async fn sample(
client: &SqlOperationsService
) -> Result<()> {
let mut list = client.list()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Trait Implementations
Sourceimpl Clone for SqlOperationsService
impl Clone for SqlOperationsService
Sourcefn clone(&self) -> SqlOperationsService
fn clone(&self) -> SqlOperationsService
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more