pub struct SqlSslCertsService { /* private fields */ }Expand description
Implements a client for the Cloud SQL Admin API.
Example
let client = SqlSslCertsService::builder().build().await?;
let response = client.delete()
/* set fields */
.send().await?;
println!("response {:?}", response);Service Description
Service to manage SSL certs for Cloud SQL instances.
Configuration
To configure SqlSslCertsService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://sqladmin.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
SqlSslCertsService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap SqlSslCertsService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl SqlSslCertsService
impl SqlSslCertsService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for SqlSslCertsService.
let client = SqlSslCertsService::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: SqlSslCertsService + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: SqlSslCertsService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn delete(&self) -> Delete
pub fn delete(&self) -> Delete
Deletes the SSL certificate. For First Generation instances, the certificate remains valid until the instance is restarted.
Example
use google_cloud_sql_v1::Result;
async fn sample(
client: &SqlSslCertsService
) -> Result<()> {
let response = client.delete()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get(&self) -> Get
pub fn get(&self) -> Get
Retrieves a particular SSL certificate. Does not include the private key (required for usage). The private key must be saved from the response to initial creation.
Example
use google_cloud_sql_v1::Result;
async fn sample(
client: &SqlSslCertsService
) -> Result<()> {
let response = client.get()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn insert(&self) -> Insert
pub fn insert(&self) -> Insert
Creates an SSL certificate and returns it along with the private key and server certificate authority. The new certificate will not be usable until the instance is restarted.
Example
use google_cloud_sql_v1::Result;
async fn sample(
client: &SqlSslCertsService
) -> Result<()> {
let response = client.insert()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list(&self) -> List
pub fn list(&self) -> List
Lists all of the current SSL certificates for the instance.
Example
use google_cloud_sql_v1::Result;
async fn sample(
client: &SqlSslCertsService
) -> Result<()> {
let response = client.list()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Trait Implementations
Sourceimpl Clone for SqlSslCertsService
impl Clone for SqlSslCertsService
Sourcefn clone(&self) -> SqlSslCertsService
fn clone(&self) -> SqlSslCertsService
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more