pub struct SqlUsersService { /* private fields */ }Expand description
Implements a client for the Cloud SQL Admin API.
Example
let client = SqlUsersService::builder().build().await?;
let response = client.delete()
/* set fields */
.send().await?;
println!("response {:?}", response);Service Description
Cloud SQL users service.
Configuration
To configure SqlUsersService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://sqladmin.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
SqlUsersService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap SqlUsersService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl SqlUsersService
impl SqlUsersService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for SqlUsersService.
let client = SqlUsersService::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: SqlUsersService + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: SqlUsersService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn delete(&self) -> Delete
pub fn delete(&self) -> Delete
Deletes a user from a Cloud SQL instance.
Example
use google_cloud_sql_v1::Result;
async fn sample(
client: &SqlUsersService
) -> Result<()> {
let response = client.delete()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get(&self) -> Get
pub fn get(&self) -> Get
Retrieves a resource containing information about a user.
Example
use google_cloud_sql_v1::Result;
async fn sample(
client: &SqlUsersService
) -> Result<()> {
let response = client.get()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn insert(&self) -> Insert
pub fn insert(&self) -> Insert
Creates a new user in a Cloud SQL instance.
Example
use google_cloud_sql_v1::Result;
async fn sample(
client: &SqlUsersService
) -> Result<()> {
let response = client.insert()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Trait Implementations
Sourceimpl Clone for SqlUsersService
impl Clone for SqlUsersService
Sourcefn clone(&self) -> SqlUsersService
fn clone(&self) -> SqlUsersService
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more