#[non_exhaustive]pub enum RecordManager {
Unspecified,
Customer,
CloudSqlAutomation,
UnknownValue(UnknownValue),
}Expand description
The system responsible for managing the DNS record.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Record manager not set. This value should not be used.
Customer
The record may be managed by the customer. It is not automatically managed by Cloud SQL automation.
CloudSqlAutomation
The record is managed by Cloud SQL, which will create, update, and delete the DNS records for the zone automatically when the Cloud SQL database instance is created or updated.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using RecordManager::value or RecordManager::name.
Implementations