#[non_exhaustive]pub enum SqlMaintenanceType {
Unspecified,
InstanceMaintenance,
ReplicaIncludedMaintenance,
InstanceSelfServiceMaintenance,
ReplicaIncludedSelfServiceMaintenance,
UnknownValue(UnknownValue),
}Expand description
The type of maintenance to be performed on the instance.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Maintenance type is unspecified.
InstanceMaintenance
Indicates that a standalone instance is undergoing maintenance. The instance can be either a primary instance or a replica.
ReplicaIncludedMaintenance
Indicates that the primary instance and all of its replicas, including cascading replicas, are undergoing maintenance. Maintenance is performed on groups of replicas first, followed by the primary instance.
InstanceSelfServiceMaintenance
Indicates that the standalone instance is undergoing maintenance, initiated by self-service. The instance can be either a primary instance or a replica.
ReplicaIncludedSelfServiceMaintenance
Indicates that the primary instance and all of its replicas are undergoing maintenance, initiated by self-service. Maintenance is performed on groups of replicas first, followed by the primary instance.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using SqlMaintenanceType::value or SqlMaintenanceType::name.
Implementations