#[non_exhaustive]pub enum SqlSuspensionReason {
Unspecified,
BillingIssue,
LegalIssue,
OperationalIssue,
KmsKeyIssue,
ProjectAbuse,
UnknownValue(UnknownValue),
}Expand description
The suspension reason of the database instance if the state is SUSPENDED.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
This is an unknown suspension reason.
BillingIssue
The instance is suspended due to billing issues (for example:, account issue)
LegalIssue
The instance is suspended due to illegal content (for example:, child pornography, copyrighted material, etc.).
OperationalIssue
The instance is causing operational issues (for example:, causing the database to crash).
KmsKeyIssue
The KMS key used by the instance is either revoked or denied access to
ProjectAbuse
The project is suspended due to abuse detected by Ares.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using SqlSuspensionReason::value or SqlSuspensionReason::name.
Implementations