#[non_exhaustive]pub enum PartialResultMode {
Unspecified,
FailPartialResult,
AllowPartialResult,
UnknownValue(UnknownValue),
}Expand description
Controls how the API should respond when the SQL execution result exceeds 10 MB.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Unspecified mode, effectively the same as FAIL_PARTIAL_RESULT.
FailPartialResult
Throw an error if the result exceeds 10 MB or if only a partial result can be retrieved. Don’t return the result.
AllowPartialResult
Return a truncated result and set partial_result to true if the result
exceeds 10 MB or if only a partial result can be retrieved due to error.
Don’t throw an error.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using PartialResultMode::value or PartialResultMode::name.
Implementations