#[non_exhaustive]pub enum UserPassword {
PasswordSecretVersion(String),
AutoIamAuthn(bool),
}Expand description
Credentials for the database connection.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
PasswordSecretVersion(String)
Optional. The resource name of the Secret Manager secret holding the
password for the user to log into the database. The secret should be
created using the regional endpoint (for API) or from the Regional
Secrets page (for UI), and stored in the same region as the Cloud SQL
instance. The expected resource name format is
projects/{project}/locations/{location}/secrets/{secret}/versions/{secret_version}.
Used together with the user field.
The secret resource name will not be stored.
AutoIamAuthn(bool)
Optional. When set to true, the API caller identity associated with the
request is used for database authentication. The API caller must be an
IAM user in the database.