#[non_exhaustive]pub enum DataApiAccess {
Unspecified,
DisallowDataApi,
AllowDataApi,
UnknownValue(UnknownValue),
}Expand description
ExecuteSql API’s access to the instance.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Unspecified, effectively the same as DISALLOW_DATA_API.
DisallowDataApi
Disallow using ExecuteSql API to connect to the instance.
AllowDataApi
Allow using ExecuteSql API to connect to the instance. For private IP instances, this allows authorized users to access the instance from the public internet using ExecuteSql API.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using DataApiAccess::value or DataApiAccess::name.
Implementations