PerformanceCaptureConfig

Struct PerformanceCaptureConfig 

#[non_exhaustive]
pub struct PerformanceCaptureConfig {
Show 14 fields pub enabled: Option<bool>, pub probing_interval_seconds: Option<i32>, pub probe_threshold: Option<i32>, pub running_threads_threshold: Option<i32>, pub seconds_behind_source_threshold: Option<i32>, pub transaction_duration_threshold: Option<i32>, pub cpu_utilization_threshold_percent: Option<i32>, pub memory_usage_threshold_percent: Option<i32>, pub transaction_lock_wait_threshold_count: Option<i32>, pub semaphore_wait_threshold_count: Option<i32>, pub history_list_length_threshold_count: Option<i32>, pub transaction_kill_threshold_seconds: Option<i32>, pub transaction_kill_excluded_user_hosts: Vec<String>, pub transaction_kill_type: Option<TransactionKillType>, /* private fields */
}
Performance capture configuration.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
enabled: Option<bool>

Optional. Enables or disables the performance capture feature.

probing_interval_seconds: Option<i32>

Optional. Specifies the interval in seconds between consecutive probes that check if any trigger condition thresholds have been reached.

probe_threshold: Option<i32>

Optional. Specifies the minimum number of consecutive probe threshold that triggers performance capture.

running_threads_threshold: Option<i32>

Optional. Specifies the minimum number of MySQL Threads_running to trigger the performance capture on the primary instance.

seconds_behind_source_threshold: Option<i32>

Optional. Specifies the minimum number of seconds replica must be lagging behind primary instance to trigger the performance capture on replica.

transaction_duration_threshold: Option<i32>

Optional. Specifies the amount of time in seconds that a transaction needs to have been open before the watcher starts recording it.

cpu_utilization_threshold_percent: Option<i32>

Optional. Specifies the minimum percentage of CPU utilization to trigger the performance capture. Valid integers range from 10 to 99. Enter 0 to disable the check.

memory_usage_threshold_percent: Option<i32>

Optional. Specifies the minimum percentage of memory usage to trigger the performance capture. Valid integers range from 10 to 99. Enter 0 to disable the check.

transaction_lock_wait_threshold_count: Option<i32>

Optional. Specifies the minimum allowed number of transactions in lock wait state to trigger the performance capture. Valid integers range from 10 to 10000. Enter 0 to disable the check.

semaphore_wait_threshold_count: Option<i32>

Optional. Specifies the minimum allowed number of semaphore waits to trigger the performance capture. Valid integers range from 10 to 10000. Enter 0 to disable the check.

history_list_length_threshold_count: Option<i32>

Optional. Specifies the minimum number of undo log entries in the history list length to trigger the performance capture. Valid integers range from 10000 to 10000000. Enter 0 to disable the check.

transaction_kill_threshold_seconds: Option<i32>

Optional. Specifies the amount of time in seconds that a transaction needs to have been open before the watcher starts terminating it. Valid integers range from 60 to 604800 (7 days). Enter 0 to disable. If enabled (i.e., > 0), this value must be greater than or equal to transaction_duration_threshold. Configurations where 0 < transaction_kill_threshold_seconds < transaction_duration_threshold will be rejected.

transaction_kill_excluded_user_hosts: Vec<String>

Optional. Specifies a customer-defined list of users to exclude from transaction termination. Entries can be in the format ‘user@host’ or just ‘user’. A standalone ‘user’ implies ‘user@%’, excluding the user from any host. Wildcard ‘%’ is allowed in the host part of the ‘user@host’ format. Example: ["app_user", "db_admin@10.1.2.3", "report_user@%"]

transaction_kill_type: Option<TransactionKillType>

Optional. Determines which transactions are allowed to be terminated when they exceed transaction_kill_threshold_seconds. This allows protecting write-heavy transactions from auto-termination if desired. Defaults to READ_ONLY_TRANSACTIONS if unspecified.

Implementations

Source

impl PerformanceCaptureConfig

pub fn new() -> Self

Creates a new default instance.

pub fn set_enabled<T>(self, v: T) -> Self
where T: Into<bool>,

Sets the value of enabled.

Example
let x = PerformanceCaptureConfig::new().set_enabled(true);
pub fn set_or_clear_enabled<T>(self, v: Option<T>) -> Self
where T: Into<bool>,

Sets or clears the value of enabled.

Example
let x = PerformanceCaptureConfig::new().set_or_clear_enabled(Some(false));
let x = PerformanceCaptureConfig::new().set_or_clear_enabled(None::<bool>);
pub fn set_probing_interval_seconds<T>(self, v: T) -> Self
where T: Into<i32>,

Sets the value of probing_interval_seconds.

Example
let x = PerformanceCaptureConfig::new().set_probing_interval_seconds(42);
pub fn set_or_clear_probing_interval_seconds<T>(self, v: Option<T>) -> Self
where T: Into<i32>,

Sets or clears the value of probing_interval_seconds.

Example
let x = PerformanceCaptureConfig::new().set_or_clear_probing_interval_seconds(Some(42));
let x = PerformanceCaptureConfig::new().set_or_clear_probing_interval_seconds(None::<i32>);
pub fn set_probe_threshold<T>(self, v: T) -> Self
where T: Into<i32>,

Sets the value of probe_threshold.

Example
let x = PerformanceCaptureConfig::new().set_probe_threshold(42);
pub fn set_or_clear_probe_threshold<T>(self, v: Option<T>) -> Self
where T: Into<i32>,

Sets or clears the value of probe_threshold.

Example
let x = PerformanceCaptureConfig::new().set_or_clear_probe_threshold(Some(42));
let x = PerformanceCaptureConfig::new().set_or_clear_probe_threshold(None::<i32>);
pub fn set_running_threads_threshold<T>(self, v: T) -> Self
where T: Into<i32>,

Sets the value of running_threads_threshold.

Example
let x = PerformanceCaptureConfig::new().set_running_threads_threshold(42);
pub fn set_or_clear_running_threads_threshold<T>(self, v: Option<T>) -> Self
where T: Into<i32>,

Sets or clears the value of running_threads_threshold.

Example
let x = PerformanceCaptureConfig::new().set_or_clear_running_threads_threshold(Some(42));
let x = PerformanceCaptureConfig::new().set_or_clear_running_threads_threshold(None::<i32>);
pub fn set_seconds_behind_source_threshold<T>(self, v: T) -> Self
where T: Into<i32>,

Sets the value of seconds_behind_source_threshold.

Example
let x = PerformanceCaptureConfig::new().set_seconds_behind_source_threshold(42);
pub fn set_or_clear_seconds_behind_source_threshold<T>( self, v: Option<T>, ) -> Self
where T: Into<i32>,

Sets or clears the value of seconds_behind_source_threshold.

Example
let x = PerformanceCaptureConfig::new().set_or_clear_seconds_behind_source_threshold(Some(42));
let x = PerformanceCaptureConfig::new().set_or_clear_seconds_behind_source_threshold(None::<i32>);
pub fn set_transaction_duration_threshold<T>(self, v: T) -> Self
where T: Into<i32>,

Sets the value of transaction_duration_threshold.

Example
let x = PerformanceCaptureConfig::new().set_transaction_duration_threshold(42);
pub fn set_or_clear_transaction_duration_threshold<T>( self, v: Option<T>, ) -> Self
where T: Into<i32>,

Sets or clears the value of transaction_duration_threshold.

Example
let x = PerformanceCaptureConfig::new().set_or_clear_transaction_duration_threshold(Some(42));
let x = PerformanceCaptureConfig::new().set_or_clear_transaction_duration_threshold(None::<i32>);
pub fn set_cpu_utilization_threshold_percent<T>(self, v: T) -> Self
where T: Into<i32>,

Sets the value of cpu_utilization_threshold_percent.

Example
let x = PerformanceCaptureConfig::new().set_cpu_utilization_threshold_percent(42);
pub fn set_or_clear_cpu_utilization_threshold_percent<T>( self, v: Option<T>, ) -> Self
where T: Into<i32>,

Sets or clears the value of cpu_utilization_threshold_percent.

Example
let x = PerformanceCaptureConfig::new().set_or_clear_cpu_utilization_threshold_percent(Some(42));
let x = PerformanceCaptureConfig::new().set_or_clear_cpu_utilization_threshold_percent(None::<i32>);
pub fn set_memory_usage_threshold_percent<T>(self, v: T) -> Self
where T: Into<i32>,

Sets the value of memory_usage_threshold_percent.

Example
let x = PerformanceCaptureConfig::new().set_memory_usage_threshold_percent(42);
pub fn set_or_clear_memory_usage_threshold_percent<T>( self, v: Option<T>, ) -> Self
where T: Into<i32>,

Sets or clears the value of memory_usage_threshold_percent.

Example
let x = PerformanceCaptureConfig::new().set_or_clear_memory_usage_threshold_percent(Some(42));
let x = PerformanceCaptureConfig::new().set_or_clear_memory_usage_threshold_percent(None::<i32>);
pub fn set_transaction_lock_wait_threshold_count<T>(self, v: T) -> Self
where T: Into<i32>,

Sets the value of transaction_lock_wait_threshold_count.

Example
let x = PerformanceCaptureConfig::new().set_transaction_lock_wait_threshold_count(42);
pub fn set_or_clear_transaction_lock_wait_threshold_count<T>( self, v: Option<T>, ) -> Self
where T: Into<i32>,

Sets or clears the value of transaction_lock_wait_threshold_count.

Example
let x = PerformanceCaptureConfig::new().set_or_clear_transaction_lock_wait_threshold_count(Some(42));
let x = PerformanceCaptureConfig::new().set_or_clear_transaction_lock_wait_threshold_count(None::<i32>);
pub fn set_semaphore_wait_threshold_count<T>(self, v: T) -> Self
where T: Into<i32>,

Sets the value of semaphore_wait_threshold_count.

Example
let x = PerformanceCaptureConfig::new().set_semaphore_wait_threshold_count(42);
pub fn set_or_clear_semaphore_wait_threshold_count<T>( self, v: Option<T>, ) -> Self
where T: Into<i32>,

Sets or clears the value of semaphore_wait_threshold_count.

Example
let x = PerformanceCaptureConfig::new().set_or_clear_semaphore_wait_threshold_count(Some(42));
let x = PerformanceCaptureConfig::new().set_or_clear_semaphore_wait_threshold_count(None::<i32>);
pub fn set_history_list_length_threshold_count<T>(self, v: T) -> Self
where T: Into<i32>,

Sets the value of history_list_length_threshold_count.

Example
let x = PerformanceCaptureConfig::new().set_history_list_length_threshold_count(42);
pub fn set_or_clear_history_list_length_threshold_count<T>( self, v: Option<T>, ) -> Self
where T: Into<i32>,

Sets or clears the value of history_list_length_threshold_count.

Example
let x = PerformanceCaptureConfig::new().set_or_clear_history_list_length_threshold_count(Some(42));
let x = PerformanceCaptureConfig::new().set_or_clear_history_list_length_threshold_count(None::<i32>);
pub fn set_transaction_kill_threshold_seconds<T>(self, v: T) -> Self
where T: Into<i32>,

Sets the value of transaction_kill_threshold_seconds.

Example
let x = PerformanceCaptureConfig::new().set_transaction_kill_threshold_seconds(42);
pub fn set_or_clear_transaction_kill_threshold_seconds<T>( self, v: Option<T>, ) -> Self
where T: Into<i32>,

Sets or clears the value of transaction_kill_threshold_seconds.

Example
let x = PerformanceCaptureConfig::new().set_or_clear_transaction_kill_threshold_seconds(Some(42));
let x = PerformanceCaptureConfig::new().set_or_clear_transaction_kill_threshold_seconds(None::<i32>);
pub fn set_transaction_kill_excluded_user_hosts<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of transaction_kill_excluded_user_hosts.

Example
let x = PerformanceCaptureConfig::new().set_transaction_kill_excluded_user_hosts(["a", "b", "c"]);
pub fn set_transaction_kill_type<T>(self, v: T) -> Self

Sets the value of transaction_kill_type.

Example
use google_cloud_sql_v1::model::performance_capture_config::TransactionKillType;
let x0 = PerformanceCaptureConfig::new().set_transaction_kill_type(TransactionKillType::ReadOnlyTransactions);
let x1 = PerformanceCaptureConfig::new().set_transaction_kill_type(TransactionKillType::AllTransactions);
pub fn set_or_clear_transaction_kill_type<T>(self, v: Option<T>) -> Self

Sets or clears the value of transaction_kill_type.

Example
use google_cloud_sql_v1::model::performance_capture_config::TransactionKillType;
let x0 = PerformanceCaptureConfig::new().set_or_clear_transaction_kill_type(Some(TransactionKillType::ReadOnlyTransactions));
let x1 = PerformanceCaptureConfig::new().set_or_clear_transaction_kill_type(Some(TransactionKillType::AllTransactions));
let x_none = PerformanceCaptureConfig::new().set_or_clear_transaction_kill_type(None::<TransactionKillType>);