This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
New values appearing in future releases of the client library, and
New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some
guidelines.
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
The default value for users that are not of type CLOUD_IAM_GROUP.
Only CLOUD_IAM_GROUP users will be inactive or active.
Users with an IamStatus of IAM_STATUS_UNSPECIFIED will not
display whether they are active or inactive as that is not applicable to
them.