#[non_exhaustive]pub enum SqlFlagType {
Unspecified,
Boolean,
String,
Integer,
None,
MysqlTimezoneOffset,
Float,
RepeatedString,
UnknownValue(UnknownValue),
}Expand description
Enum for SqlFlagType.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
This is an unknown flag type.
Boolean
Boolean type flag.
String
String type flag.
Integer
Integer type flag.
None
Flag type used for a server startup option.
MysqlTimezoneOffset
Type introduced specially for MySQL TimeZone offset. Accept a string value with the format [-12:59, 13:00].
Float
Float type flag.
RepeatedString
Comma-separated list of the strings in a SqlFlagType enum.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using SqlFlagType::value or SqlFlagType::name.
Implementations