#[non_exhaustive]pub enum ActiveDirectoryMode {
Unspecified,
ManagedActiveDirectory,
SelfManagedActiveDirectory,
CustomerManagedActiveDirectory,
UnknownValue(UnknownValue),
}Expand description
The modes of Active Directory configuration.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Unspecified mode. Will default to MANAGED_ACTIVE_DIRECTORY if the mode is not specified to maintain backward compatibility.
ManagedActiveDirectory
Managed Active Directory mode.
SelfManagedActiveDirectory
Deprecated: Use CUSTOMER_MANAGED_ACTIVE_DIRECTORY instead.
CustomerManagedActiveDirectory
Customer-managed Active Directory mode.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using ActiveDirectoryMode::value or ActiveDirectoryMode::name.
Implementations