#[non_exhaustive]pub struct PerformanceCaptureConfig {
pub enabled: Option<bool>,
pub probing_interval_seconds: Option<i32>,
pub probe_threshold: Option<i32>,
pub running_threads_threshold: Option<i32>,
pub seconds_behind_source_threshold: Option<i32>,
pub transaction_duration_threshold: Option<i32>,
/* private fields */
}Expand description
Performance capture configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enabled: Option<bool>Optional. Enables or disables the performance capture feature.
probing_interval_seconds: Option<i32>Optional. Specifies the interval in seconds between consecutive probes that check if any trigger condition thresholds have been reached.
probe_threshold: Option<i32>Optional. Specifies the minimum number of consecutive probe threshold that triggers performance capture.
running_threads_threshold: Option<i32>Optional. Specifies the minimum number of MySQL Threads_running to
trigger the performance capture on the primary instance.
seconds_behind_source_threshold: Option<i32>Optional. Specifies the minimum number of seconds replica must be lagging behind primary instance to trigger the performance capture on replica.
transaction_duration_threshold: Option<i32>Optional. Specifies the amount of time in seconds that a transaction needs to have been open before the watcher starts recording it.
Implementations
Sourceimpl PerformanceCaptureConfig
impl PerformanceCaptureConfig
Sourcepub fn set_enabled<T>(self, v: T) -> Self
pub fn set_enabled<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_enabled<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_enabled<T>(self, v: Option<T>) -> Self
Sourcepub fn set_probing_interval_seconds<T>(self, v: T) -> Self
pub fn set_probing_interval_seconds<T>(self, v: T) -> Self
Sets the value of probing_interval_seconds.
Example
let x = PerformanceCaptureConfig::new().set_probing_interval_seconds(42);Sourcepub fn set_or_clear_probing_interval_seconds<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_probing_interval_seconds<T>(self, v: Option<T>) -> Self
Sets or clears the value of probing_interval_seconds.
Example
let x = PerformanceCaptureConfig::new().set_or_clear_probing_interval_seconds(Some(42));
let x = PerformanceCaptureConfig::new().set_or_clear_probing_interval_seconds(None::<i32>);Sourcepub fn set_probe_threshold<T>(self, v: T) -> Self
pub fn set_probe_threshold<T>(self, v: T) -> Self
Sets the value of probe_threshold.
Example
let x = PerformanceCaptureConfig::new().set_probe_threshold(42);Sourcepub fn set_or_clear_probe_threshold<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_probe_threshold<T>(self, v: Option<T>) -> Self
Sets or clears the value of probe_threshold.
Example
let x = PerformanceCaptureConfig::new().set_or_clear_probe_threshold(Some(42));
let x = PerformanceCaptureConfig::new().set_or_clear_probe_threshold(None::<i32>);Sourcepub fn set_running_threads_threshold<T>(self, v: T) -> Self
pub fn set_running_threads_threshold<T>(self, v: T) -> Self
Sets the value of running_threads_threshold.
Example
let x = PerformanceCaptureConfig::new().set_running_threads_threshold(42);Sourcepub fn set_or_clear_running_threads_threshold<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_running_threads_threshold<T>(self, v: Option<T>) -> Self
Sets or clears the value of running_threads_threshold.
Example
let x = PerformanceCaptureConfig::new().set_or_clear_running_threads_threshold(Some(42));
let x = PerformanceCaptureConfig::new().set_or_clear_running_threads_threshold(None::<i32>);Sourcepub fn set_seconds_behind_source_threshold<T>(self, v: T) -> Self
pub fn set_seconds_behind_source_threshold<T>(self, v: T) -> Self
Sets the value of seconds_behind_source_threshold.
Example
let x = PerformanceCaptureConfig::new().set_seconds_behind_source_threshold(42);Sourcepub fn set_or_clear_seconds_behind_source_threshold<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_seconds_behind_source_threshold<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of seconds_behind_source_threshold.
Example
let x = PerformanceCaptureConfig::new().set_or_clear_seconds_behind_source_threshold(Some(42));
let x = PerformanceCaptureConfig::new().set_or_clear_seconds_behind_source_threshold(None::<i32>);Sourcepub fn set_transaction_duration_threshold<T>(self, v: T) -> Self
pub fn set_transaction_duration_threshold<T>(self, v: T) -> Self
Sets the value of transaction_duration_threshold.
Example
let x = PerformanceCaptureConfig::new().set_transaction_duration_threshold(42);Sourcepub fn set_or_clear_transaction_duration_threshold<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_transaction_duration_threshold<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of transaction_duration_threshold.
Example
let x = PerformanceCaptureConfig::new().set_or_clear_transaction_duration_threshold(Some(42));
let x = PerformanceCaptureConfig::new().set_or_clear_transaction_duration_threshold(None::<i32>);Trait Implementations
Sourceimpl Clone for PerformanceCaptureConfig
impl Clone for PerformanceCaptureConfig
Sourcefn clone(&self) -> PerformanceCaptureConfig
fn clone(&self) -> PerformanceCaptureConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for PerformanceCaptureConfig
impl Debug for PerformanceCaptureConfig
Sourceimpl Default for PerformanceCaptureConfig
impl Default for PerformanceCaptureConfig
Sourcefn default() -> PerformanceCaptureConfig
fn default() -> PerformanceCaptureConfig
Sourceimpl Message for PerformanceCaptureConfig
impl Message for PerformanceCaptureConfig
Sourceimpl PartialEq for PerformanceCaptureConfig
impl PartialEq for PerformanceCaptureConfig
Sourcefn eq(&self, other: &PerformanceCaptureConfig) -> bool
fn eq(&self, other: &PerformanceCaptureConfig) -> bool
self and other values to be equal, and is used by ==.